==> opennms-model-1.6.7-sources.jar: org/opennms/netmgt/model/events/EventProxyException.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//
package org.opennms.netmgt.model.events;

public class EventProxyException extends Exception {
    public EventProxyException() {
	super();
    }
    public EventProxyException(String message) {
	super(message);
    }
    public EventProxyException(String message, Throwable cause) {
	super(message, cause);
    }
    public EventProxyException(Throwable cause) {
	super(cause);
    }
}

==> opennms-model-1.9.8-sources.jar: org/opennms/netmgt/model/events/EventProxyException.java <==
//
// This file is part of the OpenNMS(R) Application.
//
// OpenNMS(R) is Copyright (C) 2006 The OpenNMS Group, Inc.  All rights reserved.
// OpenNMS(R) is a derivative work, containing both original code, included code and modified
// code that was published under the GNU General Public License. Copyrights for modified
// and included code are below.
//
// OpenNMS(R) is a registered trademark of The OpenNMS Group, Inc.
//
// Modifications:
//
// 15 Sep 2008: Add serialVersionUID (eliminate warnings) and indent. - dj@opennms.org
//
// Original code base Copyright (C) 1999-2001 Oculan Corp.  All rights reserved.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// For more information contact:
//      OpenNMS Licensing       <license@opennms.org>
//      http://www.opennms.org/
//      http://www.opennms.com/
//
package org.opennms.netmgt.model.events;

/**
 * <p>EventProxyException class.</p>
 *
 * @author ranger
 * @version $Id: $
 */
public class EventProxyException extends Exception {
    
    /**
     * 
     */
    private static final long serialVersionUID = -5163171630068781718L;

    /**
     * <p>Constructor for EventProxyException.</p>
     */
    public EventProxyException() {
        super();
    }
    
    /**
     * <p>Constructor for EventProxyException.</p>
     *
     * @param message a {@link java.lang.String} object.
     */
    public EventProxyException(String message) {
        super(message);
    }
    
    /**
     * <p>Constructor for EventProxyException.</p>
     *
     * @param message a {@link java.lang.String} object.
     * @param cause a {@link java.lang.Throwable} object.
     */
    public EventProxyException(String message, Throwable cause) {
        super(message, cause);
    }
    
    /**
     * <p>Constructor for EventProxyException.</p>
     *
     * @param cause a {@link java.lang.Throwable} object.
     */
    public EventProxyException(Throwable cause) {
        super(cause);
    }
}
